This crate corresponds to the Node API for Dora.

## Building

To build the Python module for development:

````bash
python3 -m venv .env
source .env/bin/activate
pip install maturin
maturin develop
````
